@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from nose.tools import raises
+from nose import tools
 
 from ..core import driver
 from ..core import exceptions
@@ -22,9 +22,9 @@ class Query(object):
                              globals(), locals(), ['Storage'], 0)  # noqa
 
         assert resultdriver == storage.Storage
-        assert driver.Base in resultdriver.__bases__
+        assert issubclass(resultdriver, driver.Base)
         assert resultdriver.scheme == self.scheme
 
-    @raises(exceptions.NotImplementedError)
+    @tools.raises(exceptions.NotImplementedError)
     def testFetchingNonExistentDriver(self):
         driver.fetch("nonexistentstupidlynameddriver")
